@@ -5,7 +5,7 @@ lvqinit <- function(x, cl, size, prior, k=5)
     x <- as.matrix(x)
     n <- nrow(x)
     p <- ncol(x)
-    if(length(cl) != n) stop("x and cl have different lengths")
+    if(length(cl) != n) stop("'x' and 'cl' have different lengths")
     g <- as.factor(cl)
     if(any(is.na(x)) || any(is.na(g)))
         stop("no missing values are allowed")
@@ -16,7 +16,7 @@ lvqinit <- function(x, cl, size, prior, k=5)
     if(missing(prior)) prior <- prop
     else if(any(prior <0)||round(sum(prior), 5) != 1)
         stop("invalid prior")
-    if(length(prior) != np) stop("prior is of incorrect length")
+    if(length(prior) != np) stop("'prior' is of incorrect length")
     if(missing(size)) size <- min(round(0.4 * np * (np-1+p/2),0), n)
     inside <- knn.cv(x, cl, k) == cl
     selected <- numeric(0)
@@ -37,9 +37,9 @@ olvq1 <- function(x, cl, codebk, niter = 40*nrow(codebk$x), alpha = 0.3)
     n <- nrow(x)
     p <- ncol(x)
     nc <- dim(codebk$x)[1]
-    if(length(cl) != n) stop("x and cl have different lengths")
+    if(length(cl) != n) stop("'x' and 'cl' have different lengths")
     iters <- sample(n, niter, TRUE)
-    z <- .C("VR_olvq",
+    z <- .C(VR_olvq,
             as.double(alpha),
             as.integer(n),
             as.integer(p),
@@ -49,7 +49,7 @@ olvq1 <- function(x, cl, codebk, niter = 40*nrow(codebk$x), alpha = 0.3)
             xc = as.double(codebk$x),
             as.integer(codebk$cl),
             as.integer(niter),
-            as.integer(iters-1), PACKAGE = "class"
+            as.integer(iters-1)
             )
     xc <- matrix(z$xc,nc,p)
     dimnames(xc) <- dimnames(codebk$x)
@@ -64,9 +64,9 @@ lvq1 <- function(x, cl, codebk, niter = 100*nrow(codebk$x), alpha = 0.03)
     n <- nrow(x)
     p <- ncol(x)
     nc <- dim(codebk$x)[1]
-    if(length(cl) != n) stop("x and cl have different lengths")
+    if(length(cl) != n) stop("'x' and 'cl' have different lengths")
     iters <- sample(n, niter, TRUE)
-    z <- .C("VR_lvq1",
+    z <- .C(VR_lvq1,
             as.double(alpha),
             as.integer(n),
             as.integer(p),
@@ -76,7 +76,7 @@ lvq1 <- function(x, cl, codebk, niter = 100*nrow(codebk$x), alpha = 0.03)
             xc = as.double(codebk$x),
             as.integer(codebk$cl),
             as.integer(niter),
-            as.integer(iters-1), PACKAGE = "class"
+            as.integer(iters-1)
             )
     xc <- matrix(z$xc,nc,p)
     dimnames(xc) <- dimnames(codebk$x)
@@ -92,9 +92,9 @@ lvq2 <- function(x, cl, codebk, niter = 100*nrow(codebk$x),
     n <- nrow(x)
     p <- ncol(x)
     nc <- dim(codebk$x)[1]
-    if(length(cl) != n) stop("x and cl have different lengths")
+    if(length(cl) != n) stop("'x' and 'cl' have different lengths")
     iters <- sample(n, niter, TRUE)
-    z <- .C("VR_lvq2",
+    z <- .C(VR_lvq2,
             as.double(alpha),
             as.double(win),
             as.integer(n),
@@ -105,7 +105,7 @@ lvq2 <- function(x, cl, codebk, niter = 100*nrow(codebk$x),
             xc = as.double(codebk$x),
             as.integer(codebk$cl),
             as.integer(niter),
-            as.integer(iters-1), PACKAGE = "class"
+            as.integer(iters-1)
             )
     xc <- matrix(z$xc,nc,p)
     dimnames(xc) <- dimnames(codebk$x)
@@ -121,9 +121,9 @@ lvq3 <- function(x, cl, codebk, niter = 100*nrow(codebk$x),
     n <- nrow(x)
     p <- ncol(x)
     nc <- dim(codebk$x)[1]
-    if(length(cl) != n) stop("x and cl have different lengths")
+    if(length(cl) != n) stop("'x' and 'cl' have different lengths")
     iters <- sample(n, niter, TRUE)
-    z <- .C("VR_lvq3",
+    z <- .C(VR_lvq3,
             as.double(alpha),
             as.double(win),
             as.double(epsilon),
@@ -135,7 +135,7 @@ lvq3 <- function(x, cl, codebk, niter = 100*nrow(codebk$x),
             xc = as.double(codebk$x),
             as.integer(codebk$cl),
             as.integer(niter),
-            as.integer(iters-1), PACKAGE = "class"
+            as.integer(iters-1)
             )
     xc <- matrix(z$xc,nc,p)
     dimnames(xc) <- dimnames(codebk$x)
